HTML5.1x Courseware | edX

Skip to main content
Help

## edX Help

For questions on course lectures, homework, tools, or materials for this course, post in the course discussion forum.

Have general questions about edX? You can find lots of helpful information in the edX FAQ.

Have a question about something specific? You can contact the edX general support team directly:

Report a problem Make a suggestion Ask a question

Please note: The edX support team is English speaking. While we will do our best to address your inquiry in any language, our responses will be in English.

Briefly describe your issue* Tell us the details* Include error messages, steps which lead to the issue, etc

## Thank You!

Thank you for your inquiry or feedback. We typically respond to a request within one business day (Monday to Friday, 13:00 UTC to 21:00 UTC.) In the meantime, please review our detailed FAQs where most questions have already been answered.

© All Rights Reserved

open